@@ -322,17 +322,45 @@ struct ctdb_rec_data *ctdb_marshall_loop_next(struct ctdb_marshall_buffer *m, st
 #include <sched.h>
 #endif
 
+#if HAVE_PROCINFO_H
+#include <procinfo.h>
+#endif
+
 /*
   if possible, make this task real time
  */
 void ctdb_set_scheduler(struct ctdb_context *ctdb)
 {
-#if HAVE_SCHED_SETSCHEDULER	
+#ifdef _AIX_
+#if HAVE_THREAD_SETSCHED
+	struct thrdentry64 te;
+	tid64_t ti;
+
+	ti = 0ULL;
+	if (getthrds64(getpid(), &te, sizeof(te), &ti, 1) != 1) {
+		DEBUG(DEBUG_ERR, ("Unable to get thread information\n"));
+		return;
+	}
+
+	if (ctdb->saved_scheduler_param == NULL) {
+		ctdb->saved_scheduler_param = talloc_size(ctdb, sizeof(te));
+	}
+	*(struct thrdentry64 *)ctdb->saved_scheduler_param = te;
+
+	if (thread_setsched(te.ti_tid, 0, SCHED_RR) == -1) {
+		DEBUG(DEBUG_ERR, ("Unable to set scheduler to SCHED_RR (%s)\n",
+				  strerror(errno)));
+	} else {
+		DEBUG(DEBUG_NOTICE, ("Set scheduler to SCHED_RR\n"));
+	}
+#endif
+#else /* no AIX */
+#if HAVE_SCHED_SETSCHEDULER
 	struct sched_param p;
 	if (ctdb->saved_scheduler_param == NULL) {
 		ctdb->saved_scheduler_param = talloc_size(ctdb, sizeof(p));
 	}
-	
+
 	if (sched_getparam(0, (struct sched_param *)ctdb->saved_scheduler_param) == -1) {
 		DEBUG(DEBUG_ERR,("Unable to get old scheduler params\n"));
 		return;
@@ -348,6 +376,7 @@ void ctdb_set_scheduler(struct ctdb_context *ctdb)
 		DEBUG(DEBUG_NOTICE,("Set scheduler to SCHED_FIFO\n"));
 	}
 #endif
+#endif
 }
 
 /*
@@ -355,7 +384,25 @@ void ctdb_set_scheduler(struct ctdb_context *ctdb)
  */
 void ctdb_restore_scheduler(struct ctdb_context *ctdb)
 {
-#if HAVE_SCHED_SETSCHEDULER	
+#ifdef _AIX_
+#if HAVE_THREAD_SETSCHED
+	struct thrdentry64 te, *saved;
+	tid64_t ti;
+
+	ti = 0ULL;
+	if (getthrds64(getpid(), &te, sizeof(te), &ti, 1) != 1) {
+		ctdb_fatal(ctdb, "Unable to get thread information\n");
+	}
+	if (ctdb->saved_scheduler_param == NULL) {
+		ctdb_fatal(ctdb, "No saved scheduler parameters\n");
+	}
+	saved = (struct thrdentry64 *)ctdb->saved_scheduler_param;
+	if (thread_setsched(te.ti_tid, saved->ti_pri, saved->ti_policy) == -1) {
+		ctdb_fatal(ctdb, "Unable to restore old scheduler parameters\n");
+	}
+#endif
+#else /* no AIX */
+#if HAVE_SCHED_SETSCHEDULER
 	if (ctdb->saved_scheduler_param == NULL) {
 		ctdb_fatal(ctdb, "No saved scheduler parameters\n");
 	}
@@ -363,20 +410,39 @@ void ctdb_restore_scheduler(struct ctdb_context *ctdb)
 		ctdb_fatal(ctdb, "Unable to restore old scheduler parameters\n");
 	}
 #endif
+#endif
 }
 
 void set_nonblocking(int fd)
 {
-	unsigned v;
+	int v;
+
 	v = fcntl(fd, F_GETFL, 0);
-        fcntl(fd, F_SETFL, v | O_NONBLOCK);
+	if (v == -1) {
+		DEBUG(DEBUG_WARNING, ("Failed to get file status flags - %s\n",
+				      strerror(errno)));
+		return;
+	}
+        if (fcntl(fd, F_SETFL, v | O_NONBLOCK) == -1) {
+		DEBUG(DEBUG_WARNING, ("Failed to set non_blocking on fd - %s\n",
+				      strerror(errno)));
+	}
 }
 
 void set_close_on_exec(int fd)
 {
-	unsigned v;
+	int v;
+
 	v = fcntl(fd, F_GETFD, 0);
-	fcntl(fd, F_SETFD, v | FD_CLOEXEC);
+	if (v == -1) {
+		DEBUG(DEBUG_WARNING, ("Failed to get file descriptor flags - %s\n",
+				      strerror(errno)));
+		return;
+	}
+	if (fcntl(fd, F_SETFD, v | FD_CLOEXEC) != 0) {
+		DEBUG(DEBUG_WARNING, ("Failed to set close_on_exec on fd - %s\n",
+				      strerror(errno)));
+	}
 }
 
 
@@ -467,6 +533,8 @@ bool parse_ip(const char *addr, const char *ifaces, unsigned port, ctdb_sock_add
 	char *p;
 	bool ret;
 
+	ZERO_STRUCTP(saddr); /* valgrind :-) */
+
 	/* now is this a ipv4 or ipv6 address ?*/
 	p = index(addr, ':');
 	if (p == NULL) {
@@ -655,7 +723,7 @@ int32_t get_debug_by_desc(const char *desc)
 	int i;
 
 	for (i=0; debug_levels[i].description != NULL; i++) {
-		if (!strcmp(debug_levels[i].description, desc)) {
+		if (!strcasecmp(debug_levels[i].description, desc)) {
 			return debug_levels[i].level;
 		}
 	}
@@ -761,3 +829,17 @@ void ctdb_set_runstate(struct ctdb_context *ctdb, enum ctdb_runstate runstate)
 			    runstate_to_string(runstate), runstate));
 	ctdb->runstate = runstate;
 }
+
+void ctdb_mkdir_p_or_die(struct ctdb_context *ctdb, const char *dir, int mode)
+{
+	int ret;
+
+	ret = mkdir_p(dir, mode);
+	if (ret != 0) {
+		DEBUG(DEBUG_ALERT,
+		      ("ctdb exiting with error: "
+		       "failed to create directory \"%s\" (%s)\n",
+		       dir, strerror(errno)));
+		exit(1);
+	}
+}
