@@ -24,19 +24,17 @@
 #include <sys/socket.h>
 
 /*
-  recovery daemon memdump reply address
+ * Structures to support SRVID requests and replies
  */
-struct rd_memdump_reply {
+struct srvid_request {
 	uint32_t pnn;
 	uint64_t srvid;
 };
 
-/*
-  description for a TAKEOVER_RUN message reply address
- */
-struct takeover_run_reply {
+struct srvid_request_data {
 	uint32_t pnn;
 	uint64_t srvid;
+	uint32_t data;
 };
 
 /*
@@ -109,12 +107,9 @@ struct ctdb_tunable {
 	uint32_t recovery_drop_all_ips;
 	uint32_t verify_recovery_lock;
 	uint32_t vacuum_interval;
-	uint32_t vacuum_default_interval;
 	uint32_t vacuum_max_run_time;
 	uint32_t repack_limit;
 	uint32_t vacuum_limit;
-	uint32_t vacuum_min_interval;
-	uint32_t vacuum_max_interval;
 	uint32_t max_queue_depth_drop_msg;
 	uint32_t use_status_events_for_monitoring;
 	uint32_t allow_unhealthy_db_read;
@@ -556,11 +551,11 @@ struct ctdb_context {
 
 	struct ctdb_reloadips_handle *reload_ips;
 
+	const char *nodes_file;
 	const char *public_addresses_file;
 	struct trbt_tree *child_processes; 
 
 	/* Used for locking record/db/alldb */
-	int lock_num_current;
 	int lock_num_pending;
 	struct lock_context *lock_current;
 	struct lock_context *lock_pending;
@@ -582,7 +577,6 @@ struct ctdb_db_context {
 	uint32_t seqnum;
 	struct timed_event *seqnum_update;
 	struct ctdb_traverse_local_handle *traverse;
-	bool transaction_active;
 	struct ctdb_vacuum_handle *vacuum_handle;
 	char *unhealthy_reason;
 	int pending_requests;
@@ -601,6 +595,8 @@ struct ctdb_db_context {
 	struct trbt_tree *deferred_fetch;
 
 	struct ctdb_db_statistics statistics;
+
+	int lock_num_current;
 };
 
 
@@ -776,8 +772,7 @@ struct ctdb_call_state *ctdb_call_local_send(struct ctdb_db_context *ctdb_db,
 
 
 int ctdb_start_daemon(struct ctdb_context *ctdb, bool do_fork,
-		      bool use_syslog,
-		      const char *public_address_list);
+		      bool use_syslog);
 struct ctdb_call_state *ctdbd_call_send(struct ctdb_db_context *ctdb_db, struct ctdb_call *call);
 int ctdbd_call_recv(struct ctdb_call_state *state, struct ctdb_call *call);
 
@@ -960,12 +955,6 @@ struct ctdb_marshall_buffer {
 	uint8_t data[1];
 };
 
-/* set dmaster control structure */
-struct ctdb_control_set_dmaster {
-	uint32_t db_id;
-	uint32_t dmaster;
-};
-
 /*
   structure for setting a tunable
  */
@@ -1095,6 +1084,7 @@ void ctdb_set_scheduler(struct ctdb_context *ctdb);
 void ctdb_restore_scheduler(struct ctdb_context *ctdb);
 
 struct tevent_signal *ctdb_init_sigchld(struct ctdb_context *ctdb);
+void ctdb_track_child(struct ctdb_context *ctdb, pid_t pid);
 pid_t ctdb_fork(struct ctdb_context *ctdb);
 pid_t ctdb_fork_no_free_ringbuffer(struct ctdb_context *ctdb);
 void ctdb_set_child_info(TALLOC_CTX *mem_ctx, const char *child_name_fmt, ...);
@@ -1232,10 +1222,10 @@ int ctdb_set_single_public_ip(struct ctdb_context *ctdb,
 			      const char *iface,
 			      const char *ip);
 int ctdb_set_event_script(struct ctdb_context *ctdb, const char *script);
-int ctdb_set_event_script_dir(struct ctdb_context *ctdb, const char *script_dir);
 int ctdb_set_notification_script(struct ctdb_context *ctdb, const char *script);
-void lcp2_forcerebalance(struct ctdb_context *ctdb, uint32_t pnn);
-int ctdb_takeover_run(struct ctdb_context *ctdb, struct ctdb_node_map *nodemap, client_async_callback fail_callback, void *callback_data);
+int ctdb_takeover_run(struct ctdb_context *ctdb, struct ctdb_node_map *nodemap,
+		      uint32_t *force_rebalance_nodes,
+		      client_async_callback fail_callback, void *callback_data);
 
 int32_t ctdb_control_tcp_client(struct ctdb_context *ctdb, uint32_t client_id, 
 				TDB_DATA indata);
@@ -1602,4 +1592,7 @@ struct lock_request *ctdb_lock_alldb(struct ctdb_context *ctdb,
 				     void (*callback)(void *, bool),
 				     void *private_data);
 
+int mkdir_p(const char *dir, int mode);
+void ctdb_mkdir_p_or_die(struct ctdb_context *ctdb, const char *dir, int mode);
+
 #endif
