@@ -24,7 +24,7 @@
 #ifdef SOCKPATH
 #define CTDB_PATH 	SOCKPATH
 #else
-#define CTDB_PATH 	"/tmp/ctdb.socket"
+#define CTDB_PATH 	"/var/run/ctdb/ctdbd.socket"
 #endif
 
 /* default ctdb port number */
@@ -147,10 +147,8 @@ struct ctdb_call_info {
 */
 #define CTDB_SRVID_REBALANCE_NODE 0xFB01000000000000LL
 
-/*
-   a message handler ID meaning to ask recovery master to reload all ips
- */
-#define CTDB_SRVID_RELOAD_ALL_IPS 0xFB02000000000000LL
+/* A message handler ID to stop takeover runs from occurring */
+#define CTDB_SRVID_DISABLE_TAKEOVER_RUNS 0xFB03000000000000LL
 
 /* A message id to ask the recovery daemon to temporarily disable the
    public ip checks
@@ -334,7 +332,7 @@ enum ctdb_controls {CTDB_CONTROL_PROCESS_EXISTS          = 0,
 		    CTDB_CONTROL_CHECK_SERVER_ID	 = 59,
 		    CTDB_CONTROL_GET_SERVER_ID_LIST	 = 60,
 		    CTDB_CONTROL_DB_ATTACH_PERSISTENT    = 61,
-		    CTDB_CONTROL_PERSISTENT_STORE        = 62,
+		    CTDB_CONTROL_PERSISTENT_STORE        = 62, /* obsolete */
 		    CTDB_CONTROL_UPDATE_RECORD           = 63,
 		    CTDB_CONTROL_SEND_GRATIOUS_ARP       = 64,
 		    CTDB_CONTROL_TRANSACTION_START       = 65,
@@ -355,10 +353,10 @@ enum ctdb_controls {CTDB_CONTROL_PROCESS_EXISTS          = 0,
 		    CTDB_CONTROL_GET_CAPABILITIES	 = 80,
 		    CTDB_CONTROL_START_PERSISTENT_UPDATE = 81,
 		    CTDB_CONTROL_CANCEL_PERSISTENT_UPDATE= 82,
-		    CTDB_CONTROL_TRANS2_COMMIT           = 83,
-		    CTDB_CONTROL_TRANS2_FINISHED         = 84,
-		    CTDB_CONTROL_TRANS2_ERROR            = 85,
-		    CTDB_CONTROL_TRANS2_COMMIT_RETRY     = 86,
+		    CTDB_CONTROL_TRANS2_COMMIT           = 83, /* obsolete */
+		    CTDB_CONTROL_TRANS2_FINISHED         = 84, /* obsolete */
+		    CTDB_CONTROL_TRANS2_ERROR            = 85, /* obsolete */
+		    CTDB_CONTROL_TRANS2_COMMIT_RETRY     = 86, /* obsolete */
 		    CTDB_CONTROL_RECD_PING		 = 87,
 		    CTDB_CONTROL_RELEASE_IP              = 88,
 		    CTDB_CONTROL_TAKEOVER_IP             = 89,
@@ -383,7 +381,7 @@ enum ctdb_controls {CTDB_CONTROL_PROCESS_EXISTS          = 0,
 		    CTDB_CONTROL_TRANSACTION_CANCEL      = 113,
 		    CTDB_CONTROL_REGISTER_NOTIFY         = 114,
 		    CTDB_CONTROL_DEREGISTER_NOTIFY       = 115,
-		    CTDB_CONTROL_TRANS2_ACTIVE           = 116,
+		    CTDB_CONTROL_TRANS2_ACTIVE           = 116, /* obsolete */
 		    CTDB_CONTROL_GET_LOG		 = 117,
 		    CTDB_CONTROL_CLEAR_LOG		 = 118,
 		    CTDB_CONTROL_TRANS3_COMMIT           = 119,
@@ -510,14 +508,6 @@ struct ctdb_req_keepalive {
 };
 
 
-/* types of failures possible from TRANS2_COMMIT */
-enum ctdb_trans2_commit_error {
-	CTDB_TRANS2_COMMIT_SUCCESS=0, /* all nodes committed successfully */
-	CTDB_TRANS2_COMMIT_TIMEOUT=1, /* at least one node timed out */
-	CTDB_TRANS2_COMMIT_ALLFAIL=2, /* all nodes failed the commit */
-	CTDB_TRANS2_COMMIT_SOMEFAIL=3 /* some nodes failed the commit, some allowed it */
-};
-
 /*
   the extended header for records in the ltdb
 */
