@@ -50,6 +50,12 @@ int32_t ctdb_dump_memory(struct ctdb_context *ctdb, TDB_DATA *outdata)
 	}
 	talloc_report_full(NULL, f);
 	fsize = ftell(f);
+	if (fsize == -1) {
+		DEBUG(DEBUG_ERR, (__location__ " Unable to get file size - %s\n",
+				  strerror(errno)));
+		fclose(f);
+		return -1;
+	}
 	rewind(f);
 	outdata->dptr = talloc_size(outdata, fsize);
 	if (outdata->dptr == NULL) {
@@ -65,6 +71,20 @@ int32_t ctdb_dump_memory(struct ctdb_context *ctdb, TDB_DATA *outdata)
 	return 0;
 }
 
+static int32_t control_not_implemented(const char *unsupported,
+				       const char *alternate)
+{
+	if (alternate == NULL) {
+		DEBUG(DEBUG_ERR,
+		      ("Control %s is not implemented any more\n",
+		       unsupported));
+	} else {
+		DEBUG(DEBUG_ERR,
+		      ("Control %s is not implemented any more, use %s instead\n",
+		       unsupported, alternate));
+	}
+	return -1;
+}
 
 /*
   process a control request
@@ -172,10 +192,7 @@ static int32_t ctdb_control_dispatch(struct ctdb_context *ctdb,
 		return ctdb_control_pull_db(ctdb, indata, outdata);
 
 	case CTDB_CONTROL_SET_DMASTER: 
-		CHECK_CONTROL_DATA_SIZE(sizeof(struct ctdb_control_set_dmaster));
-		DEBUG(DEBUG_ERR, ("The SET_DMASTER control is not implemented "
-				  "any more.\n"));
-		return  -1;
+		return control_not_implemented("SET_DMASTER", NULL);
 
 	case CTDB_CONTROL_PUSH_DB:
 		return ctdb_control_push_db(ctdb, indata);
@@ -428,7 +445,7 @@ static int32_t ctdb_control_dispatch(struct ctdb_context *ctdb,
 		return ctdb_control_get_server_id_list(ctdb, outdata);
 
 	case CTDB_CONTROL_PERSISTENT_STORE:
-		return ctdb_control_persistent_store(ctdb, c, indata, async_reply);
+		return control_not_implemented("PERSISTENT_STORE", NULL);
 
 	case CTDB_CONTROL_UPDATE_RECORD:
 		return ctdb_control_update_record(ctdb, c, indata, async_reply);
@@ -477,17 +494,16 @@ static int32_t ctdb_control_dispatch(struct ctdb_context *ctdb,
 
 	case CTDB_CONTROL_TRANS2_COMMIT:
 	case CTDB_CONTROL_TRANS2_COMMIT_RETRY:
-		return ctdb_control_trans2_commit(ctdb, c, indata, async_reply);
+		return control_not_implemented("TRANS2_COMMIT", "TRANS3_COMMIT");
 
 	case CTDB_CONTROL_TRANS2_ERROR:
-		return ctdb_control_trans2_error(ctdb, c);
+		return control_not_implemented("TRANS2_ERROR", NULL);
 
 	case CTDB_CONTROL_TRANS2_FINISHED:
-		return ctdb_control_trans2_finished(ctdb, c);
+		return control_not_implemented("TRANS2_FINISHED", NULL);
 
 	case CTDB_CONTROL_TRANS2_ACTIVE:
-		CHECK_CONTROL_DATA_SIZE(sizeof(uint32_t));
-		return ctdb_control_trans2_active(ctdb, c, *(uint32_t *)indata.dptr);
+		return control_not_implemented("TRANS2_ACTIVE", NULL);
 
 	case CTDB_CONTROL_TRANS3_COMMIT:
 		return ctdb_control_trans3_commit(ctdb, c, indata, async_reply);
