@@ -244,9 +244,6 @@ static int ctdb_client_destructor(struct ctdb_client *client)
 				  "commit active. Forcing recovery.\n"));
 		client->ctdb->recovery_mode = CTDB_RECOVERY_ACTIVE;
 
-		/* legacy trans2 transaction state: */
-		ctdb_db->transaction_active = false;
-
 		/*
 		 * trans3 transaction state:
 		 *
@@ -981,7 +978,7 @@ static int ux_socket_bind(struct ctdb_context *ctdb)
 
 	memset(&addr, 0, sizeof(addr));
 	addr.sun_family = AF_UNIX;
-	strncpy(addr.sun_path, ctdb->daemon.name, sizeof(addr.sun_path));
+	strncpy(addr.sun_path, ctdb->daemon.name, sizeof(addr.sun_path)-1);
 
 	/* First check if an old ctdbd might be running */
 	if (connect(ctdb->daemon.sd,
@@ -1148,7 +1145,7 @@ static void ctdb_create_pidfile(pid_t pid)
 /*
   start the protocol going as a daemon
 */
-int ctdb_start_daemon(struct ctdb_context *ctdb, bool do_fork, bool use_syslog, const char *public_address_list)
+int ctdb_start_daemon(struct ctdb_context *ctdb, bool do_fork, bool use_syslog)
 {
 	int res, ret = -1;
 	struct fd_event *fde;
@@ -1264,8 +1261,7 @@ int ctdb_start_daemon(struct ctdb_context *ctdb, bool do_fork, bool use_syslog,
 
 	initialise_node_flags(ctdb);
 
-	if (public_address_list) {
-		ctdb->public_addresses_file = public_address_list;
+	if (ctdb->public_addresses_file) {
 		ret = ctdb_set_public_addresses(ctdb, true);
 		if (ret == -1) {
 			DEBUG(DEBUG_ALERT,("Unable to setup public address list\n"));
