@@ -259,7 +259,7 @@ static int ctdb_lockall_unmark(struct ctdb_context *ctdb)
 {
 	uint32_t priority;
 
-	for (priority=NUM_DB_PRIORITIES; priority>=0; priority--) {
+	for (priority=NUM_DB_PRIORITIES; priority>0; priority--) {
 		if (ctdb_db_iterator(ctdb, priority, db_lock_unmark_handler, NULL) != 0) {
 			return -1;
 		}
@@ -279,7 +279,9 @@ static int ctdb_lock_context_destructor(struct lock_context *lock_ctx)
 	if (lock_ctx->child > 0) {
 		ctdb_kill(lock_ctx->ctdb, lock_ctx->child, SIGKILL);
 		DLIST_REMOVE(lock_ctx->ctdb->lock_current, lock_ctx);
-		lock_ctx->ctdb->lock_num_current--;
+		if (lock_ctx->ctdb_db) {
+			lock_ctx->ctdb_db->lock_num_current--;
+		}
 		CTDB_DECREMENT_STAT(lock_ctx->ctdb, locks.num_current);
 		if (lock_ctx->type == LOCK_RECORD || lock_ctx->type == LOCK_DB) {
 			CTDB_DECREMENT_DB_STAT(lock_ctx->ctdb_db, locks.num_current);
@@ -448,8 +450,11 @@ static void ctdb_lock_handler(struct tevent_context *ev,
 	}
 
 	/* Read the status from the child process */
-	read(lock_ctx->fd[0], &c, 1);
-	locked = (c == 0 ? true : false);
+	if (read(lock_ctx->fd[0], &c, 1) != 1) {
+		locked = false;
+	} else {
+		locked = (c == 0 ? true : false);
+	}
 
 	/* Update statistics */
 	CTDB_DECREMENT_STAT(lock_ctx->ctdb, locks.num_pending);
@@ -461,13 +466,11 @@ static void ctdb_lock_handler(struct tevent_context *ev,
 
 	if (locked) {
 		if (lock_ctx->ctdb_db) {
-			CTDB_INCREMENT_STAT(lock_ctx->ctdb, locks.num_current);
 			CTDB_INCREMENT_STAT(lock_ctx->ctdb, locks.buckets[id]);
 			CTDB_UPDATE_LATENCY(lock_ctx->ctdb, lock_ctx->ctdb_db,
 					    lock_type_str[lock_ctx->type], locks.latency,
 					    lock_ctx->start_time);
 
-			CTDB_INCREMENT_DB_STAT(lock_ctx->ctdb_db, locks.num_current);
 			CTDB_UPDATE_DB_LATENCY(lock_ctx->ctdb_db, lock_type_str[lock_ctx->type], locks.latency, t);
 			CTDB_INCREMENT_DB_STAT(lock_ctx->ctdb_db, locks.buckets[id]);
 		}
@@ -495,7 +498,7 @@ static void ctdb_lock_timeout_handler(struct tevent_context *ev,
 				    struct timeval current_time,
 				    void *private_data)
 {
-	const char *cmd = getenv("CTDB_DEBUG_LOCKS");
+	static const char * debug_locks = NULL;
 	struct lock_context *lock_ctx;
 	struct ctdb_context *ctdb;
 	pid_t pid;
@@ -515,13 +518,27 @@ static void ctdb_lock_timeout_handler(struct tevent_context *ev,
 		       timeval_elapsed(&lock_ctx->start_time)));
 	}
 
-	/* fire a child process to find the blocking process */
-	if (cmd != NULL) {
-		pid = fork();
-		if (pid == 0) {
-			execl(cmd, cmd, NULL);
+	/* Fire a child process to find the blocking process. */
+	if (debug_locks == NULL) {
+		debug_locks = getenv("CTDB_DEBUG_LOCKS");
+		if (debug_locks == NULL) {
+			debug_locks = talloc_asprintf(ctdb,
+						      "%s/debug_locks.sh",
+						      getenv("CTDB_BASE"));
 		}
 	}
+	if (debug_locks != NULL) {
+		pid = vfork();
+		if (pid == 0) {
+			execl(debug_locks, debug_locks, NULL);
+			_exit(0);
+		}
+		ctdb_track_child(ctdb, pid);
+	} else {
+		DEBUG(DEBUG_WARNING,
+		      (__location__
+		       " Unable to setup lock debugging - no memory?\n"));
+	}
 
 	/* reset the timeout timer */
 	// talloc_free(lock_ctx->ttimer);
@@ -726,10 +743,6 @@ static void ctdb_lock_schedule(struct ctdb_context *ctdb)
 		CTDB_NO_MEMORY_VOID(ctdb, prog);
 	}
 
-	if (ctdb->lock_num_current >= MAX_LOCK_PROCESSES_PER_DB) {
-		return;
-	}
-
 	if (ctdb->lock_pending == NULL) {
 		return;
 	}
@@ -752,8 +765,11 @@ static void ctdb_lock_schedule(struct ctdb_context *ctdb)
 						       lock_ctx->key, lock_ctx->priority,
 						       lock_ctx->type);
 			if (active_ctx == NULL) {
-				/* Found a lock context with lock requests */
-				break;
+				if (lock_ctx->ctdb_db == NULL ||
+				    lock_ctx->ctdb_db->lock_num_current < MAX_LOCK_PROCESSES_PER_DB) {
+					/* Found a lock context with lock requests */
+					break;
+				}
 			}
 
 			/* There is already a child waiting for the
@@ -796,7 +812,7 @@ static void ctdb_lock_schedule(struct ctdb_context *ctdb)
 		return;
 	}
 
-	lock_ctx->child = ctdb_fork(ctdb);
+	lock_ctx->child = vfork();
 
 	if (lock_ctx->child == (pid_t)-1) {
 		DEBUG(DEBUG_ERR, ("Failed to create a child in ctdb_lock_schedule\n"));
@@ -818,6 +834,7 @@ static void ctdb_lock_schedule(struct ctdb_context *ctdb)
 	}
 
 	/* Parent process */
+	ctdb_track_child(ctdb, lock_ctx->child);
 	close(lock_ctx->fd[1]);
 
 	talloc_set_destructor(lock_ctx, ctdb_lock_context_destructor);
@@ -859,7 +876,11 @@ static void ctdb_lock_schedule(struct ctdb_context *ctdb)
 	DLIST_REMOVE(ctdb->lock_pending, lock_ctx);
 	ctdb->lock_num_pending--;
 	DLIST_ADD_END(ctdb->lock_current, lock_ctx, NULL);
-	ctdb->lock_num_current++;
+	if (lock_ctx->ctdb_db) {
+		lock_ctx->ctdb_db->lock_num_current++;
+		CTDB_INCREMENT_STAT(lock_ctx->ctdb, locks.num_current);
+		CTDB_INCREMENT_DB_STAT(lock_ctx->ctdb_db, locks.num_current);
+	}
 }
 
 
@@ -875,7 +896,7 @@ static struct lock_request *ctdb_lock_internal(struct ctdb_context *ctdb,
 					       enum lock_type type,
 					       bool auto_mark)
 {
-	struct lock_context *lock_ctx;
+	struct lock_context *lock_ctx = NULL;
 	struct lock_request *request;
 
 	if (callback == NULL) {
@@ -883,9 +904,14 @@ static struct lock_request *ctdb_lock_internal(struct ctdb_context *ctdb,
 		return NULL;
 	}
 
+#if 0
+	/* Disable this optimization to ensure first-in-first-out fair
+	 * scheduling of lock requests */
+
 	/* get a context for this key - search only the pending contexts,
 	 * current contexts might in the middle of processing callbacks */
 	lock_ctx = find_lock_context(ctdb->lock_pending, ctdb_db, key, priority, type);
+#endif
 
 	/* No existing context, create one */
 	if (lock_ctx == NULL) {
@@ -986,7 +1012,7 @@ struct lock_request *ctdb_lock_alldb_prio(struct ctdb_context *ctdb,
 					  void (*callback)(void *, bool),
 					  void *private_data)
 {
-	if (priority < 0 || priority > NUM_DB_PRIORITIES) {
+	if (priority < 1 || priority > NUM_DB_PRIORITIES) {
 		DEBUG(DEBUG_ERR, ("Invalid db priority: %u\n", priority));
 		return NULL;
 	}
