@@ -44,6 +44,8 @@ struct ctdb_traverse_local_handle {
 	ctdb_traverse_fn_t callback;
 	bool withemptyrecords;
 	struct tevent_fd *fde;
+	int records_failed;
+	int records_sent;
 };
 
 /*
@@ -56,12 +58,25 @@ static void ctdb_traverse_child_handler(struct tevent_context *ev, struct tevent
 							struct ctdb_traverse_local_handle);
 	ctdb_traverse_fn_t callback = h->callback;
 	void *p = h->private_data;
-	char res;
+	int res;
+	ssize_t n;
+
+	/* Read the number of records sent by traverse child */
+	n = read(h->fd[0], &res, sizeof(res));
+	if (n < 0 || n != sizeof(res)) {
+		/* Traverse child failed */
+		DEBUG(DEBUG_ERR, ("Local traverse failed db:%s reqid:%d\n",
+				  h->ctdb_db->db_name, h->reqid));
+	} else if (res < 0) {
+		/* Traverse failed */
+		res = -res;
+		DEBUG(DEBUG_ERR, ("Local traverse failed db:%s reqid:%d records:%d\n",
+				  h->ctdb_db->db_name, h->reqid, res));
+	} else {
+		DEBUG(DEBUG_INFO, ("Local traverse end db:%s reqid:%d records:%d\n",
+				   h->ctdb_db->db_name, h->reqid, res));
+	}
 
-	/* FIXME: There is no way to distinguish between failed traverse and
-	 * successful traverse.  The only way to signal the end is by sending
-	 * tdb_null for key and data. */
-	read(h->fd[0], &res, 1);
 	callback(p, tdb_null, tdb_null);
 }
 
@@ -106,6 +121,7 @@ static int ctdb_traverse_local_fn(struct tdb_context *tdb, TDB_DATA key, TDB_DAT
 	d = ctdb_marshall_record(h, h->reqid, key, NULL, data);
 	if (d == NULL) {
 		/* error handling is tricky in this child code .... */
+		h->records_failed++;
 		return -1;
 	}
 
@@ -115,9 +131,11 @@ static int ctdb_traverse_local_fn(struct tdb_context *tdb, TDB_DATA key, TDB_DAT
 	res = ctdb_control(h->ctdb_db->ctdb, h->srcnode, 0, CTDB_CONTROL_TRAVERSE_DATA,
 			   CTDB_CTRL_FLAG_NOREPLY, outdata, NULL, NULL, &status, NULL, NULL);
 	if (res != 0 || status != 0) {
+		h->records_failed++;
 		return -1;
 	}
 
+	h->records_sent++;
 	return 0;
 }
 
@@ -177,25 +195,57 @@ static struct ctdb_traverse_local_handle *ctdb_traverse_local(struct ctdb_db_con
 
 	if (h->child == 0) {
 		/* start the traverse in the child */
-		char res = 0;
+		int res, status;
 		pid_t parent = getpid();
+		struct ctdb_context *ctdb = ctdb_db->ctdb;
+		struct ctdb_rec_data *d;
+		TDB_DATA outdata;
 
 		close(h->fd[0]);
 
 		ctdb_set_process_name("ctdb_traverse");
-		if (switch_from_server_to_client(ctdb_db->ctdb,
-						 "traverse_local-%s:",
+		if (switch_from_server_to_client(ctdb, "traverse_local-%s:",
 						 ctdb_db->db_name) != 0) {
 			DEBUG(DEBUG_CRIT, ("Failed to switch traverse child into client mode\n"));
-			res = -1;
+			_exit(0);
 		}
 
-		if (tdb_traverse_read(ctdb_db->ltdb->tdb, ctdb_traverse_local_fn, h) != 0) {
-			res = -1;
+		d = ctdb_marshall_record(h, h->reqid, tdb_null, NULL, tdb_null);
+		if (d == NULL) {
+			res = 0;
+			write(h->fd[1], &res, sizeof(int));
+			_exit(0);
 		}
-		write(h->fd[1], &res, 1);
 
-		while (ctdb_kill(ctdb_db->ctdb, parent, 0) == 0 || errno != ESRCH) {
+		res = tdb_traverse_read(ctdb_db->ltdb->tdb, ctdb_traverse_local_fn, h);
+		if (res == -1 || h->records_failed > 0) {
+			/* traverse failed */
+			res = -(h->records_sent);
+		} else {
+			res = h->records_sent;
+		}
+
+		/* Wait till all the data is flushed from output queue */
+		while (ctdb_queue_length(ctdb->daemon.queue) > 0) {
+			tevent_loop_once(ctdb->ev);
+		}
+
+		/* End traverse by sending empty record */
+		outdata.dptr = (uint8_t *)d;
+		outdata.dsize = d->length;
+		ret = ctdb_control(ctdb, h->srcnode, 0,
+				   CTDB_CONTROL_TRAVERSE_DATA,
+				   CTDB_CTRL_FLAG_NOREPLY, outdata,
+				   NULL, NULL, &status, NULL, NULL);
+		if (ret == -1 || status == -1) {
+			if (res > 0) {
+				res = -res;
+			}
+		}
+
+		write(h->fd[1], &res, sizeof(res));
+
+		while (ctdb_kill(ctdb, parent, 0) == 0 || errno != ESRCH) {
 			sleep(5);
 		}
 		_exit(0);
@@ -279,6 +329,7 @@ struct traverse_start_state {
 	uint32_t db_id;
 	uint64_t srvid;
 	bool withemptyrecords;
+	int num_records;
 };
 
 
@@ -381,6 +432,9 @@ static struct ctdb_traverse_all_handle *ctdb_daemon_traverse_all(struct ctdb_db_
 		return NULL;
 	}
 
+	DEBUG(DEBUG_NOTICE,("Starting traverse on DB %s (id %d)\n",
+			    ctdb_db->db_name, state->reqid));
+
 	/* timeout the traverse */
 	event_add_timed(ctdb->ev, state, 
 			timeval_current_ofs(ctdb->tunable.traverse_timeout, 0), 
@@ -390,35 +444,14 @@ static struct ctdb_traverse_all_handle *ctdb_daemon_traverse_all(struct ctdb_db_
 }
 
 /*
-  called for each record during a traverse all 
+  called when local traverse ends
  */
 static void traverse_all_callback(void *p, TDB_DATA key, TDB_DATA data)
 {
 	struct traverse_all_state *state = talloc_get_type(p, struct traverse_all_state);
-	int ret;
-	struct ctdb_rec_data *d;
-	TDB_DATA cdata;
 
-	d = ctdb_marshall_record(state, state->reqid, key, NULL, data);
-	if (d == NULL) {
-		/* darn .... */
-		DEBUG(DEBUG_ERR,("Out of memory in traverse_all_callback\n"));
-		return;
-	}
-
-	cdata.dptr = (uint8_t *)d;
-	cdata.dsize = d->length;
-
-	ret = ctdb_daemon_send_control(state->ctdb, state->srcnode, 0, CTDB_CONTROL_TRAVERSE_DATA,
-				       0, CTDB_CTRL_FLAG_NOREPLY, cdata, NULL, NULL);
-	if (ret != 0) {
-		DEBUG(DEBUG_ERR,("Failed to send traverse data\n"));
-	}
-
-	if (key.dsize == 0 && data.dsize == 0) {
-		/* we're done */
-		talloc_free(state);
-	}
+	/* we're done */
+	talloc_free(state);
 }
 
 /*
@@ -643,6 +676,10 @@ static void traverse_start_callback(void *p, TDB_DATA key, TDB_DATA data)
 
 	ctdb_dispatch_message(state->ctdb, state->srvid, cdata);
 	if (key.dsize == 0 && data.dsize == 0) {
+		DEBUG(DEBUG_NOTICE, ("Ending traverse on DB %s (id %d), records %d\n",
+				     state->h->ctdb_db->db_name, state->h->reqid,
+				     state->num_records));
+
 	    	if (state->h->timedout) {
 		    	/* timed out, send TRAVERSE_KILL control */
 			talloc_free(state);
@@ -651,6 +688,8 @@ static void traverse_start_callback(void *p, TDB_DATA key, TDB_DATA data)
 			talloc_set_destructor(state, NULL);
 			talloc_free(state);
 		}
+	} else {
+		state->num_records++;
 	}
 }
 
@@ -706,8 +745,7 @@ int32_t ctdb_control_traverse_start_ext(struct ctdb_context *ctdb,
 	state->db_id = d->db_id;
 	state->ctdb = ctdb;
 	state->withemptyrecords = d->withemptyrecords;
-
-	DEBUG(DEBUG_NOTICE,("Stating traverse on DB %s\n", ctdb_db->db_name));
+	state->num_records = 0;
 
 	state->h = ctdb_daemon_traverse_all(ctdb_db, traverse_start_callback, state);
 	if (state->h == NULL) {
