@@ -9,7 +9,4 @@ define_test "knfsd down, 6 iterations"
 setup_nfs
 rpc_services_down "nfs"
 
-iterate_test 6 'ok_null' \
-    2 'rpc_set_service_failure_response "nfsd"' \
-    4 'rpc_set_service_failure_response "nfsd"' \
-    6 'rpc_set_service_failure_response "nfsd"'
+iterate_test 10 'rpc_set_service_failure_response "nfsd"'
