@@ -311,6 +311,51 @@ setup_ctdb ()
     export CTDB_PARTIALLY_ONLINE_INTERFACES
 }
 
+setup_memcheck ()
+{
+    setup_ctdb
+
+    _swap_total="5857276"
+
+    if [ "$1" = "bad" ] ; then
+	_swap_free="   4352"
+	_mem_cached=" 112"
+	_mem_free=" 468"
+    else
+	_swap_free="$_swap_total"
+	_mem_cached="1112"
+	_mem_free="1468"
+    fi
+
+    export FAKE_PROC_MEMINFO="\
+MemTotal:        3940712 kB
+MemFree:          225268 kB
+Buffers:          146120 kB
+Cached:          1139348 kB
+SwapCached:        56016 kB
+Active:          2422104 kB
+Inactive:        1019928 kB
+Active(anon):    1917580 kB
+Inactive(anon):   523080 kB
+Active(file):     504524 kB
+Inactive(file):   496848 kB
+Unevictable:        4844 kB
+Mlocked:            4844 kB
+SwapTotal:       ${_swap_total} kB
+SwapFree:        ${_swap_free} kB
+..."
+
+    export FAKE_FREE_M="\
+             total       used       free     shared    buffers     cached
+Mem:          3848       3634        213          0        142       ${_mem_cached}
+-/+ buffers/cache:       2379       ${_mem_free}
+Swap:         5719        246       5473"
+
+    export CTDB_MONITOR_FREE_MEMORY
+    export CTDB_MONITOR_FREE_MEMORY_WARN
+    export CTDB_CHECK_SWAP_IS_NOT_USED
+}
+
 ctdb_get_interfaces ()
 {
     # The echo/subshell forces all the output onto 1 line.
@@ -599,7 +644,7 @@ setup_nfs ()
 setup_nfs_ganesha ()
 {
     setup_nfs "$@"
-    export NFS_SERVER_MODE="ganesha"
+    export CTDB_NFS_SERVER_MODE="ganesha"
     if [ "$1" != "down" ] ; then
 	export CTDB_MANAGES_NFS="yes"
     fi
@@ -792,6 +837,29 @@ setup_httpd ()
 
 ######################################################################
 
+# multipathd fakery
+
+setup_multipathd ()
+{
+    for i ; do
+	case "$i" in
+	    \!*)
+		_t="${i#!}"
+		echo "Marking ${_t} as having no active paths"
+		FAKE_MULTIPATH_FAILURES="${FAKE_MULTIPATH_FAILURES}${FAKE_MULTIPATH+FAILURES:+ }${_t}"
+		;;
+	    *)
+		_t="$i"		
+	esac
+	CTDB_MONITOR_MPDEVICES="${CTDB_MONITOR_MPDEVICES}${CTDB_MONITOR_MPDEVICES:+ }${_t}"
+    done
+
+    export CTDB_MONITOR_MPDEVICES FAKE_MULTIPATH_FAILURES
+    export FAKE_SLEEP_FORCE=0.1
+}
+
+######################################################################
+
 # Result and test functions
 
 # Set some globals and print the summary.
@@ -841,11 +909,13 @@ simple_test ()
     _extra_header=$(_extra_header)
 
     echo "Running eventscript \"$script $event${1:+ }$*\""
-    _trace=""
+    _shell=""
     if $TEST_COMMAND_TRACE ; then
-	_trace="sh -x"
+	_shell="sh -x"
+    else
+	_shell="sh"
     fi
-    _out=$($_trace "${CTDB_BASE}/events.d/$script" "$event" "$@" 2>&1)
+    _out=$($_shell "${CTDB_BASE}/events.d/$script" "$event" "$@" 2>&1)
 
     result_check "$_extra_header"
 }
@@ -938,11 +1008,13 @@ iterate_test ()
 	    shift 2
 	fi
 
-	_trace=""
+	_shell=""
 	if $TEST_COMMAND_TRACE ; then
-	    _trace="sh -x"
+	    _shell="sh -x"
+	else
+	    _shell="sh"
 	fi
-	_out=$($_trace "${CTDB_BASE}/events.d/$script" "$event" $args 2>&1)
+	_out=$($_shell "${CTDB_BASE}/events.d/$script" "$event" $args 2>&1)
 	_rc=$?
 
     if [ -n "$OUT_FILTER" ] ; then
